@@ -32,7 +32,7 @@ from Crypto.Cipher import AES
 from hashlib import md5
 
 
-class KaisaCrypto():
+class KaisaCrypto(object):
 
     def __init__(self):
 
